/******************************************************************************

   FILE				: main.c
   
   AUTHOR			: Axiom Manufacturing    					     
						  Spencer Ruggles
						  
	PURPOSE			: Manufacturing Test for EVB51JM128 board, x427
 
 ******************************************************************************
 
  Purpose:
  
  Manufacturing Functional Test routine for EVB51JM128 board, x427.  

******************************************************************************/

#include "hidef.h"				// for EnableInterrupts macro
#include "derivative.h"			// include peripheral declarations 
#include "peripheral.h"			// peripheral function includes 


void main(void) {

	SOPT1 = 0x00;					// disable COP watchdog
	DisableInterrupts;			// disable interrupts
	
	// Timer2 Setup
	TPM2SC_PS = div16;			// load prescalar value
	TPM2MODH = 0xFF;				// timer count high
	TPM2MODL = 0xFF;				// timer count low
  	
	// Parallel IO Setup
	PTCD |= PTCD_PTCD6_MASK | PTCD_PTCD4_MASK;	// init PTCD[6,4]
	PTCDD |= PTCD_PTCD6_MASK | PTCD_PTCD4_MASK;	//PTCD[6,4] output

	PTCD |= PTCD_PTCD2_MASK;	// init PTDD2
	PTDDD |= PTDD_PTDD2_MASK;	//	PTDD2 output
	
	PTED |= PTED_PTED3_MASK | PTED_PTED2_MASK;	// init PTED[3:2]
	PTEDD |= PTEDD_PTEDD3_MASK | PTEDD_PTEDD2_MASK;	// PTED[3:2] output

	PTFD |= PTFDD_PTFDD5_MASK | PTFD_PTFD1_MASK | PTFD_PTFD0_MASK;	// init PTFD[5,1:0]
	PTFDD |= PTFDD_PTFDD5_MASK | PTFDD_PTFDD1_MASK | PTFDD_PTFDD0_MASK;	// PTFD[5,1:0] otuput
										
	PTGPE |= PTGD_PTGD0_MASK | PTGD_PTGD1_MASK | PTGD_PTGD2_MASK | PTGD_PTGD3_MASK;
										// PTGD[3:0] pull enabled for SW test

	// PBSW interrupt service routine
  	interrupt 87 void SWtest() {
  		switch(PTGD) {
  			case 1;
  				PTFD &= ~PTFD_PTFD5_MASK;	// LED5 on
  				dly2();							// wait
  				PTFD |= PTFD_PTFD5_MASK;	// LED5 off
  				break;
  			case 2;
  				PTDD &= ~PTDD_PTDD5_MASK;	// LED5 on
  				dly2();							// wait
  				PTDD |= PTDD_PTDD5_MASK;	// LED5 off
 				break;
  			case 3;
  				PTCD &= ~PTCD_PTCD4_MASK;	// LED6 on
  				dly2();							// wait
  				PTCD |= PTCD_PTCD5_MASK;	// LED6 off
  				break;
  			case 4;
  				PTCD &= ~PTCD_PTCD6_MASK;	// LED5 on
  				dly2();							// wait
  				PTCD |= PTCD_PTCD6_MASK;	// LED5 off
 				break;
  				
  		}
  	}
  	while(1) {

		ledtest();					// call led test
  	}
	
	
}

