/******************************************************************************

   FILE				: atd.c

   AUTHOR			: Axiom Manufacturing
						  Spencer Ruggles

	PURPOSE			: Mfg Test for EVB51JM128 board, x427

 ******************************************************************************

  Purpose:

  Mfg Functional Test routine for EVB51JM128 board, x427.

******************************************************************************/

#include "MCF51JM128.h"			// include peripheral declarations 
#include "atd.h"					// include ATD declarations
#include "sci.h"					// include SCI functions


void adcinit() {
	
	ADCSC1_ADCO = 0;				// single conversion selected
	ADCCFG_MODE = 0;				// 8 bit result
	ADCCFG_ADICLK = 0;			// select busclk input
	ADCCFG_ADIV = 0;				// input clock div 1
	APCTL1 = 0x0F;					// CH[3:0] pins for ATD use
	APCTL2 = 0x0F;					// CH[11:8] pins for ATD use
}

byte adconv(byte chsel) {

	ADCSC1_ADCH = chsel;			// initiate conversion
	while(!ADCSC1_COCO);			// wait for conversion to complete
}

/*******************************************************************************
ATDTest

	display "Press Any Key to Continue" message on COM1 port then reads 
	pot analog input until kb key pressed.  POT analog results output to COM1
	
	INPUT:	POT Channel to test	2 = POT input - ADP2, 9=POT input - ADP9
	OUTPUT:	none
********************************************************************************/
void ATDTest(byte adch) {

	PressAnyKey(0);							// send string
	while(SerialReady(0)) {
		adconv(adch);						// convert ATD input
		DisplayATD(0);						// display POT results
		putchar(0,CR);							// send CR
	}
}

/*******************************************************************************
acctest

	display "Press Any Key to Continue" message on COM1 port then reads 
	accel sensor analog inputs (X, Y, Z) until kb key pressed.  Sensor analog 
	results output to COM1
	
	INPUT:	none
	OUTPUT:	none
********************************************************************************/
void acctest(byte chx, byte chy, byte chz) {

	PressAnyKey(0);						// send string
	while(SerialReady(0)) {
		adconv(chx);						// convert ATD input
		DisplayATD(0);						// display POT results
		adconv(chy);						// convert ATD input
		DisplayATD(0);						// display POT results
		adconv(chz);						// convert ATD input
		DisplayATD(0);						// display POT results
		putchar(0,CR);							// send CR
	}
}
