/******************************************************************************

   FILE				: main.c
   
   AUTHOR			: Axiom Manufacturing    					     
						  Spencer Ruggles
						  
	PURPOSE			: Manufacturing Test for EVB51JM128 board, x427
 
 ******************************************************************************
 
  Purpose:
  
  Manufacturing Functional Test routine for EVB51JM128 board, x427.  

******************************************************************************/

#include "hidef.h"				// for EnableInterrupts macro
#include "derivative.h"			// include peripheral declarations 
#include "peripheral.h"			// include peripheral function declarations  
#include "sci.h"					// include SCI declarations
#include "atd.h"					// include ATD declarations 

void main(void){

	byte sel;						// select variable
	
	DisableInterrupts;			// disable interrupts

/******************************************************************************
	write MGCTRIM value by hand until final JM128 SP released  
	current release does not write NVMGCTRM value
******************************************************************************/

	MCGTRM = 0xAE;
	MCGSC_FTRIM = 0x01;

	init();									// initialize MCU
	ensci(0);								// initialize COM1
	ensci(1);								// initialize COM2
	adcinit();								// initialize ATD

	while(1) {
		cls(0);								// clear COM1 display
		display_menu(0);					// formatted ASCII output display
//		puts(1,com2str);				   // send data to COM2	
		
		sel = char2hex(GetSByte(0));
		switch(sel) {							// wait for selection input from kb
			case 1:	acctest(3, 0, 1); break;	// Accel Test
			case 2:	ledtest(); break;		// LED Test
			case 3:	swtest(); break;		// PushButton Switch Test
			case 4:	ATDTest(11); break;	// Light Sensor Test
			case 5:	ATDTest(10); break;	// Temp Sensor Test
			case 6:	ATDTest(2); break;	// POT Test on PTB2
			case 7:	BTest(); break;		// Buzzer Test
			case 8:	CANTest(); break;		// CAN Port Test
			case 9:	LCDTest(); break;		// LCD Test
		}
	}
}

